Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(270)

Unified Diff: third_party/WebKit/Source/core/dom/Fullscreen.cpp

Issue 1373773003: Implement 'window.isSecureContext'. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: document. Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/dom/Fullscreen.cpp
diff --git a/third_party/WebKit/Source/core/dom/Fullscreen.cpp b/third_party/WebKit/Source/core/dom/Fullscreen.cpp
index 110dec35632e5025f4c97611f0e4d89f4a900b58..f4ea213cc22fa3b62ef2422afd9711f69c220aa5 100644
--- a/third_party/WebKit/Source/core/dom/Fullscreen.cpp
+++ b/third_party/WebKit/Source/core/dom/Fullscreen.cpp
@@ -200,11 +200,11 @@ void Fullscreen::documentWasDisposed()
void Fullscreen::requestFullscreen(Element& element, RequestType requestType)
{
// It is required by isPrivilegedContext() but isn't
// actually used. This could be used later if a warning is shown in the
// developer console.
String errorMessage;
- if (document()->isPrivilegedContext(errorMessage)) {
+ if (document()->isSecureContext(errorMessage)) {
UseCounter::count(document(), UseCounter::FullscreenSecureOrigin);
} else {
UseCounter::count(document(), UseCounter::FullscreenInsecureOrigin);
@@ -200,11 +200,11 @@ void Fullscreen::documentWasDisposed()
void Fullscreen::requestFullscreen(Element& element, RequestType requestType)
{
- // It is required by isPrivilegedContext() but isn't
+ // It is required by isSecureContext() but isn't
// actually used. This could be used later if a warning is shown in the
// developer console.
« no previous file with comments | « third_party/WebKit/Source/core/dom/ExecutionContext.h ('k') | third_party/WebKit/Source/core/frame/DOMWindow.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698